@@ -1,10 +1,7 @@
 use clap::{App, Arg, ArgMatches, Values};
 
-#[cfg(not(target_arch = "wasm32"))]
 pub mod check;
-#[cfg(not(target_arch = "wasm32"))]
 pub mod generate;
-
 pub mod import;
 pub mod solve;
 
@@ -13,6 +10,14 @@ use std::io::{stdout, BufWriter, Write};
 use std::process;
 use std::str::FromStr;
 
+pub(crate) fn create_write_buffer(out_file: Option<File>) -> BufWriter<Box<dyn Write>> {
+    if let Some(out_file) = out_file {
+        BufWriter::new(Box::new(out_file))
+    } else {
+        BufWriter::new(Box::new(stdout()))
+    }
+}
+
 fn open_file(path: &str, description: &str) -> File {
     File::open(path).unwrap_or_else(|err| {
         eprintln!("Cannot open {} file '{}': '{}'", description, path, err.to_string());
@@ -27,14 +32,6 @@ fn create_file(path: &str, description: &str) -> File {
     })
 }
 
-fn create_write_buffer(out_file: Option<File>) -> BufWriter<Box<dyn Write>> {
-    if let Some(out_file) = out_file {
-        BufWriter::new(Box::new(out_file))
-    } else {
-        BufWriter::new(Box::new(stdout()))
-    }
-}
-
 // TODO avoid code duplication (macros?)
 
 fn parse_float_value<T: FromStr<Err = std::num::ParseFloatError>>(
