@@ -38,8 +38,8 @@ pub struct Config {
 #[derive(Clone, Deserialize, Debug)]
 #[serde(rename_all = "camelCase")]
 pub struct EvolutionConfig {
-    initial: Option<InitialConfig>,
-    population: Option<PopulationType>,
+    pub initial: Option<InitialConfig>,
+    pub population: Option<PopulationType>,
 }
 
 #[derive(Clone, Deserialize, Debug)]
@@ -514,7 +514,7 @@ fn configure_from_termination(mut builder: Builder, termination_config: &Option<
     if let Some(config) = termination_config {
         builder = builder.with_max_time(config.max_time);
         builder = builder.with_max_generations(config.max_generations);
-        builder = builder.with_cost_variation(config.variation.as_ref().map(|v| (v.sample, v.cv)));
+        builder = builder.with_min_cv(config.variation.as_ref().map(|v| (v.sample, v.cv)));
     }
 
     builder
